Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(295)

Unified Diff: sdk/lib/io/socket.dart

Issue 925403002: Add the shared flag to HttpServer as well (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/io/socket.dart
diff --git a/sdk/lib/io/socket.dart b/sdk/lib/io/socket.dart
index 08f973e695c476a2a18b60fe195518f2140de251..50fc24e17ee3c3456adb726e1c7be5edf6ebdd4d 100644
--- a/sdk/lib/io/socket.dart
+++ b/sdk/lib/io/socket.dart
@@ -223,6 +223,14 @@ abstract class RawServerSocket implements Stream<RawSocket> {
* backlog for the underlying OS listen setup. If [backlog] has the
* value of [:0:] (the default) a reasonable value will be chosen by
* the system.
+ *
+ * The optional argument [shared] specify whether additional binds
+ * to the same `address`, `port` and `v6Only` combination is
+ * possible from the same Dart process. If `shared` is `true` and
+ * additional binds are preformed, then the incoming (accepted)
kustermann 2015/02/17 11:30:56 preformed -> performed
Søren Gjesse 2015/02/17 12:53:11 Done.
+ * connections will be distributed between that set
+ * `RawServerSocket`s. One way of using this is to have number of
+ * isolates between which incoming connections are distributed.
*/
external static Future<RawServerSocket> bind(address,
int port,
@@ -249,8 +257,9 @@ abstract class RawServerSocket implements Stream<RawSocket> {
/**
* Get the [RawServerSocketReference].
*
* WARNING: This feature is *highly experimental* and currently only works on
* Linux. The API is most likely going to change in the near future.
*
* The returned [RawServerSocketReference] can be used to create other
* [RawServerSocket]s listening on the same port,
@@ -260,6 +269,9 @@ abstract class RawServerSocket implements Stream<RawSocket> {
* The [RawServerSocketReference] can be distributed to other isolates through
* a [RawSendPort].
*/
+
+ @Deprecated('This will be removed in Dart 1.10. '
+ 'Use the `shared` optional argument on the `bind` method instead.')
kustermann 2015/02/17 11:30:56 long line.
Søren Gjesse 2015/02/17 12:53:11 Done.
RawServerSocketReference get reference;
}
@@ -270,6 +282,7 @@ abstract class RawServerSocket implements Stream<RawSocket> {
* WARNING: This class is used with [RawServerSocket.reference] which is highly
* experimental.
*/
+@Deprecated('This will be removed in Dart 1.10.')
abstract class RawServerSocketReference {
/**
* Create a new [RawServerSocket], from this reference.
@@ -315,6 +328,14 @@ abstract class ServerSocket implements Stream<Socket> {
* backlog for the underlying OS listen setup. If [backlog] has the
* value of [:0:] (the default) a reasonable value will be chosen by
* the system.
+ *
+ * The optional argument [shared] specify whether additional binds
+ * to the same `address`, `port` and `v6Only` combination is
+ * possible from the same Dart process. If `shared` is `true` and
+ * additional binds are preformed, then the incoming (incoming)
kustermann 2015/02/17 11:30:56 ditto
Søren Gjesse 2015/02/17 12:53:11 Done.
+ * connections will be distributed between that set
+ * `ServerSocket`s. One way of using this is to have number of
+ * isolates between which incoming connections are distributed.
*/
external static Future<ServerSocket> bind(address,
int port,
@@ -341,8 +362,9 @@ abstract class ServerSocket implements Stream<Socket> {
/**
* Get the [ServerSocketReference].
*
* WARNING: This feature is *highly experimental* and currently only works on
* Linux. The API is most likely going to change in the near future.
*
* The returned [ServerSocketReference] can be used to create other
* [ServerSocket]s listening on the same port,
@@ -352,6 +374,8 @@ abstract class ServerSocket implements Stream<Socket> {
* The [ServerSocketReference] can be distributed to other isolates through a
* [SendPort].
*/
+ @Deprecated('This will be removed in Dart 1.10. '
+ 'Use the `shared` optional argument on the `bind` method instead.')
kustermann 2015/02/17 11:30:56 long line
Søren Gjesse 2015/02/17 12:53:11 Done.
ServerSocketReference get reference;
}
@@ -362,6 +386,7 @@ abstract class ServerSocket implements Stream<Socket> {
* WARNING: This class is used with [ServerSocket.reference] which is highly
* experimental.
*/
+@Deprecated('This will be removed in Dart 1.10.')
abstract class ServerSocketReference {
/**
* Create a new [ServerSocket], from this reference.
@@ -249,8 +257,9 @@ abstract class RawServerSocket implements Stream<RawSocket> {
* Get the [RawServerSocketReference].
*
- * WARNING: This feature is *highly experimental* and currently only works on
- * Linux. The API is most likely going to change in the near future.
+ * WARNING: This feature is *highly experimental* and currently only
+ * works on Linux. The API will be removed in Dart 1.10. Use the
+ * `shared` optional argument on the `bind` method instead.
*
* The returned [RawServerSocketReference] can be used to create other
@@ -341,8 +362,9 @@ abstract class ServerSocket implements Stream<Socket> {
* Get the [ServerSocketReference].
*
- * WARNING: This feature is *highly experimental* and currently only works on
- * Linux. The API is most likely going to change in the near future.
+ * WARNING: This feature is *highly experimental* and currently only
+ * works on Linux. The API will be removed in Dart 1.10. Use the
+ * `shared` optional argument on the `bind` method instead.
*
* The returned [ServerSocketReference] can be used to create other

Powered by Google App Engine
This is Rietveld 408576698